#
# spec file for package discord
#
# Copyright (c) 2023 SUSE LLC.
# Copyright (c) 2021 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Require bash for extglob in install section.
%global _buildshell /bin/bash
# Shipped by this package but not provided externally
%global __requires_exclude ^libffmpeg
%global __provides_exclude_from %{_libdir}/%{name}
# This is to enable build with patent encoumbered codecs. Not allowed in OBS
%bcond_with x264
Name:           discord
Version:        0.0.38
Release:        1.1
Summary:        Voice and Text Chat for Gamers
License:        SUSE-NonFree
Group:          Productivity/Networking/Instant Messenger
URL:            https://discordapp.com/
Source0:        https://dl.discordapp.net/apps/linux/%{version}/%{name}-%{version}.tar.gz
#Source0:        https://discordapp.com/api/download?platform=linux&format=tar.gz
Source2:        discord-symbolic.svg
Source3:        https://raw.githubusercontent.com/flathub/com.discordapp.Discord/master/com.discordapp.Discord.appdata.xml
# Disable breaking updates which will prompt users to download a deb or tar
# file and lock them out of Discord making the program unusable. Courtesy of
# NixOS contributors and the original author (@lionirdeadman), kudos to them.
Source4:        https://raw.githubusercontent.com/NixOS/nixpkgs/master/pkgs/applications/networking/instant-messengers/discord/disable-breaking-updates.py
Source99:       PERMISSION
ExclusiveArch:  x86_64
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  unzip
Requires:       libatomic1
Requires(post): python3-base
Conflicts:      discord


#Patent free ffmpeg config
#Snippets from https://github.com/orionhealth/electron-packager-plugin-non-proprietary-codecs-ffmpeg/blob/master/src/downloadFFMPEG.js
%define electronVersion 24.1.3
%define ffmpegarch x64
%define ffmpegplatform linux
%define ffmpegFileName ffmpeg-v%{electronVersion}-%{ffmpegplatform}-%{ffmpegarch}.zip
#eg. https://github.com/electron/electron/releases/download/v1.6.11/ffmpeg-v1.6.11-linux-x64.zip
Source1: https://github.com/electron/electron/releases/download/v%{electronVersion}/%{ffmpegFileName}


%description
Discord is a voice and text chat for gamers. The Text chat supports
inline images and videos. Voice chat includes a jitter buffer,
automatic gain control, noise suppression, echo cancellation.
Server-to-client communications are encrypted.

%prep
%setup -q -n Discord
%setup -q -T -a 1 -c -n ffmpeg

%build
%if %{with x264}
# nothing to do
:
%else
rm %{_builddir}/Discord/libffmpeg.so
cp %{_builddir}/ffmpeg/libffmpeg.so %{_builddir}/Discord/
%endif

%install
cd %{_builddir}/Discord
install -Dm644 discord.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
desktop-file-install \
  --dir=%{buildroot}%{_datadir}/applications \
  --set-key=Exec \
  --set-value=%{_bindir}/%{name} \
  %{name}.desktop

install -Dm755 chrome-sandbox %{buildroot}%{_libdir}/%{name}/chrome-sandbox
install -Dm755 libffmpeg.so %{buildroot}%{_libdir}/%{name}/libffmpeg.so
install -Dm755 libEGL.so %{buildroot}%{_libdir}/%{name}/libEGL.so
install -Dm755 libGLESv2.so %{buildroot}%{_libdir}/%{name}/libGLESv2.so
install -Dm644 %{SOURCE2} %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps/%{name}-symbolic.svg
install -Dm644 %{SOURCE3} %{buildroot}%{_datadir}/appdata/com.discordapp.Discord.appdata.xml

# install share
mkdir -p %{buildroot}%{_libdir}/%{name}
shopt -s extglob
cp -r !(discord*|*.so) %{buildroot}%{_libdir}/%{name}
shopt -u extglob

# fix missing icon in some environments
ln -sf %{_datadir}/icons/hicolor/256x256/apps/%{name}.png %{buildroot}%{_libdir}/%{name}

# Executable checks for resources in its directory so it cannot be in bin.
mkdir -p %{buildroot}%{_bindir}
ln -s %{_libdir}/%{name}/Discord %{buildroot}%{_bindir}/%{name}

# disable-breaking-updates.py script
install -v -m 644 %{SOURCE4} %{buildroot}%{_libdir}/%{name}/
sed -i -e '/@pythonInterpreter@/d' \
       -e 's,@configDirName@,discord,' \
       -e '/print("\[Nix]/ s/Nix/Discord/' \
  %{buildroot}%{_libdir}/%{name}/disable-breaking-updates.py

%post
%if 0%{?suse_version} < 1500
%desktop_database_post
%endif
chmod 0755 %{_libdir}/%{name}/Discord

if command -v python3 > /dev/null; then
  python3 %{_libdir}/%{name}/disable-breaking-updates.py
fi

%if 0%{?suse_version} < 1500
%postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root)
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
%{_datadir}/icons/hicolor/symbolic/apps/%{name}-symbolic.svg
%{_datadir}/appdata/com.discordapp.Discord.appdata.xml
%{_libdir}/%{name}

%changelog
* Tue Dec 12 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.0.38:
  * No upstream release notes.
* Tue Dec  5 2023 Tomas Cech <sleep_walker@opensuse.org>
- Update to version 0.0.37:
  * No upstream release notes.
* Tue Nov 28 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.0.36:
  * No upstream release notes.
* Mon Nov 13 2023 Tomas Cech <sleep_walker@opensuse.org>
- Update to version 0.0.35:
  * No upstream release notes.
* Mon Nov  6 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.0.34:
  * No upstream release notes.
* Wed Nov  1 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.0.33:
  * No upstream release notes.
* Tue Oct 17 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.0.32:
  * No upstream release notes.
* Thu Oct  5 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.0.31:
  * No upstream release notes.
* Mon Sep 18 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.0.30:
  * No upstream release notes.
* Wed Aug 30 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.0.29:
  * No upstream release notes.
* Tue Jul 11 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.0.28:
  * No upstream release notes.
* Fri Apr 28 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 0.0.27:
  * No upstream release notes.
- Updated Electron to version 24.1.3.
- Update com.discordapp.Discord.appdata.xml
- Add disable-breaking-updates.py script from NixOS/nixpkgs GitHub
  repo (based on the version from flathub/com.discordapp.Discord).
  This should disable the auto updating mechanism when Discord is
  launched, and prevent it from locking out the user when the app
  identifies a new version was released upstream, but our package
  hasn't being updated yet.
* Fri Mar 31 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.0.26 of 2023-03-30
* Mon Feb 20 2023 Fabian Vogt <fvogt@suse.com>
- Use %%_provides_exclude_from instead
- Only the libffmpeg.so requires needs to be ignored
* Sun Feb 19 2023 Jon Brightwell <jon@moozaad.co.uk>
- Updated provides and requires ignores for libGLES, libvulkan and libEGL so it doesn't clash with system packages
* Tue Feb 14 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 0.0.25 of 2023-02-14
* Sun Jan 15 2023 Victor Kwan <vkwan8@uwo.ca>
- Update to 0.0.24 of 2023-01-14
  * Updated Electron version to 13.6.6
* Sat Dec 10 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 0.0.22 of 2022-12-10
  * No upstream release notes.
* Sun Oct 23 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 0.0.21 of 2022-10-22
  * No upstream release notes.
* Thu Sep 15 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 0.0.20 of 2022-09-15
  * No upstream release notes.
* Thu Aug 11 2022 Michiel van der Wulp <michiel.vanderwulp@gmail.com> - 0.0.19
- Update to 0.0.19 of 2022-08-08
  * No upstream release notes.
* Wed Jun  8 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 0.0.18
  * No upstream release notes.
* Thu Feb 17 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 0.0.17
  * No upstream release notes.
* Thu Jan 13 2022 Maurizio Galli <maurizio.galli@suse.com>
- Add explicit runtime libatomic1 dependency which is not autodetected
* Sun Oct 31 2021 Matthias Mailänder <mailaender@opensuse.org>
- Fix screenshot URLs
* Thu Oct 14 2021 Mathias Homann <Mathias.Homann@opensuse.org>
- Let's do properly autodetected dependencies.
* Wed Oct 13 2021 Mathias Homann <Mathias.Homann@opensuse.org>
- Fix for boo#1191555 - libc++1 has been stripped from the requirements
    on Tumbleweed and is not even needed anymore.
* Wed Sep 22 2021 Matthias Mailänder <mailaender@opensuse.org>
- Update to 0.0.16
* Tue May 25 2021 Mathias Homann <Mathias.Homann@opensuse.org>
- Update to 0.0.15
  * No upstream release notes.
* Tue Apr 27 2021 Jon Brightwell <jon@moozaad.co.uk>
- reverted to working electron-ffmpeg v10.4.3
* Thu Mar 25 2021 Tamara Schmitz <tamara.schmitz@suse.com>
- Update electron-ffmpeg to v12.0.2
- Update com.discordapp.Discord.appdata.xml
* Wed Mar 24 2021 George Vassilev <george.vassilev91@gmail.com>
- Version update : 0.0.14
* Sat Dec  5 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.0.13
* Thu Sep 10 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.0.12
- fixed wrong files installed
* Thu Aug  6 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.0.11
* Sat Jun 13 2020 Matthias Mailänder <mailaender@opensuse.org>
- Add metadata for https://en.opensuse.org/openSUSE:AppStore
- Fix file permissions
- Adhere to https://en.opensuse.org/openSUSE:Package_group_guidelines
* Mon Jun  8 2020 Maurizio Galli <maurizio.galli@gmail.com>
- ffmpeg macro no longer used in packman. Switch to x264.
* Thu Mar 26 2020 Stasiek Michalski <stasiek@michalski.cc>
- Install symbolic icon for GNOME
* Fri Mar  6 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Use ffmpeg as bcond since it already exists in Packman
* Wed Feb 26 2020 Jimmy Berry <jimmy@boombatower.com>
- Update to version 0.0.10
  * No upstream release notes.
- Remove installation of libVkICD_mock_icd.so which was removed
- Install chrome-sandbox which was added
- Correct indentation in spec and changes files.
* Mon Feb 24 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Added bcond to allow building with embedded libffmpeg.so. This
  will allow building the package with patent encoumbered codecs
  in Packman.
* Thu Oct 17 2019 Jan Engelhardt <jengelh@inai.de>
- Utilize the new proposed tag scheme for the Group line,
  selecting a more appropriate categorization than "game".
  (Discord, while being related to gaming, is not a game per se.)
* Tue Mar 12 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.0.9
  * No upstream release notes.
* Wed Jan 16 2019 Jon Brightwell <jon@moozaad.co.uk>
- Update to version 0.0.8
  Update to version ffmpeg 4.0.1
  * no upstream release notes
* Sat Nov 17 2018 Maurizio Galli <maurizio.galli@gmail.com>
- added symbolic link to fix missing icon in some environments
* Tue May  1 2018 jimmy@boombatower.com
- Update to version 0.0.5.
  * No upstream release notes.
* Wed Feb  7 2018 jimmy@boombatower.com
- Wrap desktop post/postun scripts for suse_version < 1500.
* Fri Jan 19 2018 jimmy@boombatower.com
- Add PERMISSION as source.
* Fri Jan 19 2018 jon@moozaad.co.uk
- Added PERMISSION file with email from Discord Inc.
* Tue Jan  9 2018 jimmy@boombatower.com
- Update to version 0.0.4.
* Sun Dec 17 2017 jon@moozaad.co.uk
- Dropped the "- added libc++ dep somewhere." Redone.
* Sun Dec 17 2017 jon@moozaad.co.uk
- renamed from discord-npe to discord for non-oss naming compliance
- version v0.0.3
- added libc++ dep
* Wed Dec  6 2017 jon@moozaad.co.uk
- Added non patent encumbered ffmpeg
* Fri Aug 11 2017 jimmy@boombatower.com
- Update to version 0.0.2.
* Wed Feb  1 2017 jimmy@boombatower.com
- Move application files to %%{_libdir} instead of %%{_data_dir}
  to avoid arch-dependent-file-in-usr-share (Badness: 590).
- Remove patchelf and rpmlintrc as they are no longer required.
* Sat Jan 28 2017 jengelh@inai.de
- Update description
- Enforce bash for building for extglob
* Thu Jan 26 2017 jimmy@boombatower.com
- Initial package.
